@@ -67,7 +67,10 @@ class BumpSpline:
                     val -= dy
                     yy[i] = math.sqrt(dy)
 
-            r = leastsq(self.spline_error, yy)
+            # with epsfcn too low, the optimizer may not recognize changes
+            # while calculating Jacobian and would skip optimizing some of
+            # the parameters
+            r = leastsq(self.spline_error, yy, epsfcn = 1e-6)
             self.make_spline(r[0])
             self.spline_ready = True
         except:
@@ -89,6 +92,7 @@ class BumpSpline:
             self.spline = PchipInterpolator(self.xx, yy)
 
     def spline_error(self, pars):
+        #print(pars)
         self.make_spline(pars)
         return self.curr_error()
 
